<?php
class Ship2Anywhere_Admin
{
    private $plugin_name;
    private $version;

    public function __construct($plugin_name, $version)
    {
        $this->plugin_name = $plugin_name;
        $this->version = $version;
    }

    public function enqueue_styles()
    {
        wp_enqueue_style($this->plugin_name, plugin_dir_url(__FILE__) . 'css/ship2anywhere-admin.css', array(), $this->version, 'all');
    }

    public function enqueue_scripts()
    {
        wp_enqueue_script($this->plugin_name, plugin_dir_url(__FILE__) . 'js/ship2anywhere-admin.js', array('jquery', 'select2'), $this->version, false);
    }

    public function plugin_action_links($links)
    {
        if (Ship2Anywhere_Utility::is_woocommerce_enabled()) {
            $settings_link = '<a href="'
            . admin_url('admin.php?page=wc-settings&tab=shipping&section=ship2anywhere_rules')
            . '" title="' . esc_attr(__('View Settings', $this->plugin_name))
            . '">' . __('Settings', $this->plugin_name) . '</a>';

            $actions_links = [
                'settings' => $settings_link,
            ];
            return array_merge($actions_links, $links);
        }

        return $links;
    }

    public function plugin_row_meta($links, $file)
    {
        if ($file === SHIP2ANYWHERE_PLUGIN_BASE_NAME) {
            $quick_start_guide_link = '<a href="'
            . esc_url(apply_filters('bbamastro_docs_url', 'https://bbamastro.atlassian.net/wiki/download/attachments/363561064/BBA_Woocommerce_wordpress_QuickStartGuide_final.pdf?version=1&modificationDate=1522813629916&cacheVersion=1&api=v2&download=true'))
            . '" title="' . esc_attr(__('View Documentation', 'bbamastro'))
            . '">' . __('Quickstart Guide', 'bbamastro') . '</a>';
            $row_meta = [
                'Quick Start Guide' => $quick_start_guide_link,
            ];
            return array_merge($links, $row_meta);
        }

        return (array) $links;
    }

    public function on_plugin_loaded()
    {
        if (Ship2Anywhere_Utility::is_woocommerce_enabled()) {
            $this->require_admin_dependecies();
            new Ship2Anywhere_Shipping_Rules();
            new Ship2Anywhere_Custom_Order_Fields();
            new Ship2Anywhere_Custom_Order_Fields_Shop_Order();
            new Ship2Anywhere_Custom_WP_API();
            new Ship2Anywhere_Webhook();
        }
    }

    private function require_admin_dependecies()
    {
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-ship2anywhere-shipping-rules.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-ship2anywhere-custom-order-fields-config.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-ship2anywhere-custom-order-fields.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-ship2anywhere-custom-order-fields-shop-order.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-ship2anywhere-custom-wp-api.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-ship2anywhere-webhook.php';
    }
}
