<?php
class Ship2Anywhere_Api
{
    protected $token;
    protected $api_url;
    protected $auth_url;

    private $client_id = "clientapp";
    private $client_secret = "123456";
    private $auth_code = "Basic Y2xpZW50YXBwOjEyMzQ1Ng==";
    private $reseller_id = 62;

    public function __construct()
    {
        $this->auth_url = Ship2Anywhere_Utility::get_config('auth_url', null);
        $this->api_url = Ship2Anywhere_Utility::get_config('api_url', null);
    }

    public function authenticate()
    {
        $headers = [
            'Authorization' => $this->auth_code,
            'Origin' => Ship2Anywhere_Utility::set_header_origin_value()
        ];

        $body = [
            'username' => Ship2Anywhere_Utility::get_config('acc_username', null),
            'password' => Ship2Anywhere_Utility::get_config('acc_password', null),
            'client_id' => $this->client_id,
            'client_secret' => $this->client_secret,
            'grant_type' => 'password',
            'reseller_id' => $this->reseller_id
        ];

        $args = [
            'headers' => $headers,
            'body' => $body
        ];

        $response = wp_remote_post($this->auth_url, $args);
        if (is_wp_error($response)) {
            return null; // error occured
        }

        $result = json_decode($response['body']);
        if (!is_object($result)) { return null; }

        return $result->access_token; 
    }

    public function send_api_request($method, $action, $queries = [], $params = [])
    {
        $url = $this->api_url . Ship2Anywhere_Utility::trim_action($action);
        if (!empty($queries)) {
            $url_query = Ship2Anywhere_Utility::create_url_query($queries);
            $url = $url . '?' . implode('&', $url_query);
        }

        $headers = [
            'Authorization' => 'Bearer ' . esc_attr($_SESSION[SHIP2ANYWHERE_TOKEN]),
            'Origin' => Ship2Anywhere_Utility::set_header_origin_value(),
            'Content-Type' => 'application/json',
        ];

        $body = json_encode($params, true);
        $args = [
            'headers' => $headers,
            'body' => $body,
            'method' => $method,
            'data_format' => 'body',
            'timeout'     => 500,
        ];

        $response = wp_remote_request($url, $args);
        if (is_wp_error($response)) {
            return null; // error occured
        }

        $result = json_decode($response['body']);
        return $result;
    }
}
