<?php
class Ship2Anywhere_Custom_Order_Fields
{
    private $page_id;

    public function __construct()
    {
        $this->define_custom_order_fields_hooks();
    }

    private function define_custom_order_fields_hooks()
    {
        add_option(SHIP2ANYWHERE_ADMIN_CUSTOM_ORDER_FIELD_NEXT_FIELD_ID, 1);
        add_option(SHIP2ANYWHERE_ADMIN_CUSTOM_ORDER_FIELDS);

        add_action('admin_menu', array($this, 'add_menu_link'));
        add_action('woocommerce_email_after_order_table', array($this, 'add_custom_order_fields_to_email'), 20, 3);
        add_action('wp_insert_post', array($this, 'save_default_field_values'), 10, 2);

        $this->generate_fields();
    }

    private function generate_fields()
    {
        if (!get_option(SHIP2ANYWHERE_ADMIN_CUSTOM_ORDER_FIELDS)) {
            $fields = [
                $this->generate_next_field_id() => [
                    "label" => "Tracking Number",
                    "description" => SHIP2ANYWHERE_COMPANY_NAME . " Tracking Number",
                    "type" => "text",
                    "visible" => true,
                    "listable" => true,
                    "sortable" => true,
                    "filterable" => true,
                ],
                $this->generate_next_field_id() => [
                    "label" => "Consignment Number",
                    "description" => SHIP2ANYWHERE_COMPANY_NAME . " Consignment Number",
                    "type" => "text",
                    "visible" => true,
                    "listable" => false,
                    "sortable" => false,
                    "filterable" => false,
                ],
            ];

            update_option(SHIP2ANYWHERE_ADMIN_CUSTOM_ORDER_FIELDS, $fields);
        }
    }

    private function generate_next_field_id()
    {
        $next_field_id = get_option(SHIP2ANYWHERE_ADMIN_CUSTOM_ORDER_FIELD_NEXT_FIELD_ID);
        update_option(SHIP2ANYWHERE_ADMIN_CUSTOM_ORDER_FIELD_NEXT_FIELD_ID, ++$next_field_id);
        return $next_field_id;
    }

    public function add_menu_link()
    {
        $this->page_id = add_submenu_page(
            'woocommerce',
            __('Tracking And Consignment Fields', SHIP2ANYWHERE_ADMIN_CUSTOM_ORDER_FIELDS),
            __('Tracking And Consignment Fields', SHIP2ANYWHERE_ADMIN_CUSTOM_ORDER_FIELDS),
            'manage_woocommerce',
            SHIP2ANYWHERE_ADMIN_CUSTOM_ORDER_FIELDS,
            array($this, 'render_page')
        );
    }

    public function render_page()
    {
        include_once plugin_dir_path(dirname(__FILE__)) . 'admin/partials/ship2anywhere-custom-order-fields-partial.php';
    }

    public function save_default_field_values($post_id, $post)
    {
        if ('shop_order' === $post->post_type) {
            foreach (Ship2Anywhere_Utility::get_order_fields() as $order_field) {
                if ($order_field->default) {
                    add_post_meta($post_id, $order_field->get_meta_key(), $order_field->default, true);
                }
            }
        }
    }

    public function add_custom_order_fields_to_email($order, $_, $plain_text)
    {
        $order_fields = Ship2Anywhere_Utility::get_order_fields($this->get_prop($order, 'id'), true);
        if (empty($order_fields)) {
            return;
        }

        $template = $plain_text ? 'emails/ship2anywhere-custom-order-fields-plain.php' : 'ship2anywhere-custom-order-fields.php';
        wc_get_template(
            $template,
            array('order_fields' => $order_fields),
            '',
            plugin_dir_path(dirname(__FILE__)) . 'admin/partials/'
        );
    }

    private function get_prop($object, $prop, $context = 'edit')
    {
        if ('shipping_total' == $prop && 'view' !== $context) {
            $prop = 'order_shipping';
        } elseif ('parent_id' === $prop) {
            return $object->$post->post_parent;
        }

        $value = '';

        if (is_callable(array($object, "get_{$prop}"))) {
            $value = $object->{"get_{$prop}"}($context);
        }

        return $value;
    }
}
