<?php
class Ship2Anywhere_Utility
{
    public static function is_woocommerce_enabled()
    {
        return class_exists('woocommerce') ? true : false;
    }

    public static function get_config($key, $default = null)
    {
        $settings = get_option(SHIP2ANYWHERE_RULES_SETTINGS, null);
        if (is_array($settings) && !empty($settings[$key])) {
            return $settings[$key];
        }

        return $default;
    }

    public static function set_header_origin_value()
    {
        $api_url = self::get_config('api_url', null);
        switch ($api_url) {
            case "https://api-demo.bbamastro.com":
                return "https://dashboard-demo.bbamastro.com";
                break;
            case "https://api.bbamastro.com":
                return "https://dashboard.bbamastro.com";
                break;
        }
    }

    public static function trim_action($action)
    {
        if ($action) {
            $action = '/' . trim($action, '/') . '/';
        }

        return $action;
    }

    public static function create_url_query($vars = [])
    {
        $result = [];
        foreach ($vars as $name => $value) {
            $result[] = $name . '=' . $value;
        }
        return $result;
    }

    public static function logger($log_data, $label, $source, $as_json = false)
    {
        $logger = wc_get_logger();
        $context = ['source' => SHIP2ANYWHERE_PLUGIN_BASE_NAME . '-' . $source];
        $logger->debug("============ $label ===============");
        $logger->debug($as_json ? json_encode($log_data) : var_dump($log_data), $context);
    }

    public static function get_order_fields($order_id = null, $return_all = null)
    {
        $order_fields = [];
        $order = $order_id ? wc_get_order($order_id) : null;
        $custom_order_fields = get_option(SHIP2ANYWHERE_ADMIN_CUSTOM_ORDER_FIELDS);

        if (!is_array($custom_order_fields)) {
            $custom_order_fields = [];
        }

        foreach ($custom_order_fields as $field_id => $field) {
            $order_field = new Ship2Anywhere_Custom_Order_Fields_Config($field_id, $field);
            $has_value = false;

            if ($order instanceof WC_Order) {
                $set_value = false;
                $value = '';

                if (metadata_exists('post', $order_id, $order_field->get_meta_key())) {
                    $set_value = true;
                    $value = $order->get_meta($order_field->get_meta_key(), true, 'edit');
                }

                if ($set_value) {
                    $order_field->set_value($value);
                    $has_value = true;
                }
            }

            if ($return_all || $has_value) {
                $order_fields[$field_id] = $order_field;
            }
        }

        return $order_fields;
    }

}
