<?php
class Ship2Anywhere_Webhook
{
    public function __construct()
    {
        add_filter('woocommerce_rest_prepare_product_object', array($this, 'prepare_products'));
        add_action('woocommerce_webhook_payload', array($this, 'generate_webhook_payload'));
    }

    public function generate_webhook_payload($payload)
    {
        if ($payload['order_key']) {
            $shipping_data = $payload['shipping_lines'][0]['meta_data'][0];
            $payload['shipping_lines'][0]['method_id'] = $this->get_method_id($shipping_data);
            $payload['product_categories'] = $this->get_product_categories($payload['line_items']);

            return $payload;
        }

        if ($payload['name']) {
            if (empty($payload['sku'])) {
                $payload['sku'] = $payload['id'];
                return $payload;
            }
        }

        return $payload;
    }

    private function get_method_id($shipping_data)
    {
        if (is_object($shipping_data)) {
            $shipping = $shipping_data->get_data();
            return $shipping['value'];
        }

        return $shipping_data['value'];
    }

    private function get_product_categories($line_items)
    {
        if (!empty($line_items)) {
            foreach ($line_items as $value) {
                $product = wc_get_product($value['product_id']);
                $categories = $product->get_categories();
                $payload['product_categories'] = [];

                if (is_array($categories)) {
                    foreach ($categories as $cat) {
                        array_push($payload['product_categories'], strip_tags($cat));
                    }
                } else {
                    array_push($payload['product_categories'], strip_tags($categories));
                }
            }
        }
    }

    public function prepare_products($response)
    {
        $data = $response->get_data();
        if(empty($data['sku'])){
            $data['sku'] = $data['id'];
            $response->set_data($data);
        }
        return $response;
    }
}
