<?php
class Ship2Anywhere
{
    protected $loader;
    protected $plugin_name;
    protected $version;

    public function __construct()
    {
        if (defined('SHIP2ANYWHERE_VERSION')) {
            $this->version = SHIP2ANYWHERE_VERSION;
        } else {
            $this->version = '1.0.0';
        }

        $this->plugin_name = 'ship2anywhere';

        $this->load_dependencies();
        $this->set_locale();
        $this->define_admin_hooks();
        $this->define_public_hooks();
    }

    private function load_dependencies()
    {
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-ship2anywhere-utility.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-ship2anywhere-loader.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-ship2anywhere-i18n.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-ship2anywhere-api.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'admin/class-ship2anywhere-admin.php';
        require_once plugin_dir_path(dirname(__FILE__)) . 'public/class-ship2anywhere-public.php';

        $this->loader = new Ship2Anywhere_Loader();
    }

    private function set_locale()
    {
        $plugin_i18n = new Ship2Anywhere_i18n();
        $this->loader->add_action('plugin_loaded', $plugin_i18n, 'load_plugin_textdomain');
    }

    private function define_admin_hooks()
    {
        $plugin_admin = new Ship2Anywhere_Admin($this->get_plugin_name(), $this->get_version());

        $this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_styles');
        $this->loader->add_action('admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts');
        $this->loader->add_action('plugins_loaded', $plugin_admin, 'on_plugin_loaded');

        $this->loader->add_filter('plugin_action_links_' . SHIP2ANYWHERE_PLUGIN_BASE_NAME, $plugin_admin, 'plugin_action_links');
        $this->loader->add_filter('plugin_row_meta', $plugin_admin, 'plugin_row_meta', 10, 2);
    }

    private function define_public_hooks()
    {
        $plugin_public = new Ship2Anywhere_Public($this->get_plugin_name(), $this->get_version());

        $this->loader->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_styles');
        $this->loader->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_scripts');
        $this->loader->add_action('plugins_loaded', $plugin_public, 'on_plugin_loaded');
    }

    public function run()
    {
        $this->loader->run();
    }

    public function get_plugin_name()
    {
        return $this->plugin_name;
    }

    public function get_loader()
    {
        return $this->loader;
    }

    public function get_version()
    {
        return $this->version;
    }
}
